Publications
============
Links to publications and associate source code.

Nempy Technical Brief
---------------------
The nempy technical brief is available :download:`here  <../../docs/pdfs/Nempy Technical Brief v1.0.0.pdf>`.
as pdf, and is also used as the introduction for readthedocs page. The code below uses Nempy v1.1.0 which is
now superseded v2.0.0.

Source code for Figure 1
************************

.. literalinclude:: ../../publications/all_features_example.py
    :linenos:
    :language: python

Source code for Figure 2
************************

.. literalinclude:: ../../publications/energy_only_market.py
    :linenos:
    :language: python
